@@ -23,7 +23,7 @@ limUserName = os.environ['LIMUSERNAME'].replace('"', '')
 limPassword = os.environ['LIMPASSWORD'].replace('"', '')
 
 calltries = 50
-sleep = 2.5
+sleep = 0.5
 
 headers = {
     'Content-Type': 'application/xml',
@@ -37,9 +37,9 @@ def get_session():
     retry_adapter = HTTPAdapter(
         max_retries=Retry(
             total=3,
-            status_forcelist=[429, 500, 502, 503, 504],
-            method_whitelist=["HEAD", "GET", "OPTIONS"],
             backoff_factor=2,
+            allowed_methods=["HEAD", "GET", "OPTIONS"],
+            status_forcelist=[429, 500, 502, 503, 504],
         ),
     )
     session = requests.Session()
